Major audio format handler cleanups.
[paraslash.git] / client.h
index 1c9a8c22ae4dabd73a20547c8ce6bc195989e218..c6d5c75d1ebf1e70a7dbeafa5ca10f60a2e00592 100644 (file)
--- a/client.h
+++ b/client.h
@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 1997-2006 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 1997-2009 Andre Noll <maan@systemlinux.org>
  *
- *     This program is free software; you can redistribute it and/or modify
- *     it under the terms of the GNU General Public License as published by
- *     the Free Software Foundation; either version 2 of the License, or
- *     (at your option) any later version.
- *
- *     This program is distributed in the hope that it will be useful,
- *     but WITHOUT ANY WARRANTY; without even the implied warranty of
- *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *     GNU General Public License for more details.
- *
- *     You should have received a copy of the GNU General Public License
- *     along with this program; if not, write to the Free Software
- *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
+ * Licensed under the GPL v2. For licencing details see COPYING.
  */
 
 /** \file client.h common client functions and exported symbols from client_common.c */
@@ -44,12 +32,13 @@ enum {
        CL_RECEIVING,
 };
 
+/** size of the receiving buffer */
 #define CLIENT_BUFSIZE 8192
 
 /**
  * data specific to a client task
  */
-struct private_client_data {
+struct client_task {
        /** the state of the connection */
        int status;
        /** the file descriptor */
@@ -68,10 +57,8 @@ struct private_client_data {
        RC4_KEY rc4_send_key;
        /** the client task structure */
        struct task task;
-       /** non-zero if task is unregistered */
-       int eof;
        /** the buffer used for handshake and receiving */
-       char buf[CLIENT_BUFSIZE];
+       char *buf;
        /** number of bytes loaded in \p buf */
        size_t loaded;
        /** non-zero if the pre_select hook added \p fd to the read fd set */
@@ -84,13 +71,10 @@ struct private_client_data {
        char *inbuf;
        /** number of bytes loaded in \p inbuf */
        size_t *in_loaded;
-       /** non-zero if input task encountered an eof or an errro condition */
-       int *in_eof;
+       /** Non-zero if input task encountered an eof or an error condition. */
+       int *in_error;
 };
 
-int client_open(struct private_client_data *pcd);
-void client_close(struct private_client_data *pcd);
-int client_parse_config(int argc, char *argv[],
-       struct private_client_data **pcd_ptr);
-void client_pre_select(struct sched *s, struct task *t);
-void client_post_select(struct sched *s, struct task *t);
+void client_close(struct client_task *ct);
+int client_open(int argc, char *argv[], struct client_task **ct,
+               int *loglevel);